==> spread-5.1.0.48-py3-none-any.whl: spread_dashboard/dali/views.py <==
from django.views.generic import TemplateView

from spread_core import mqtt
from spread_core.bam.dali.providers import lights
from spread_core.bam.dali import managers
from ..project import bam
from ..responses import Success


class DaliDimmer(TemplateView):
    template_name = 'dali/dimmer.html'

    def get(self, request, *args, **kwargs):
        provider_id = kwargs.get('id')
        if request.GET:
            return Success(True)
        return self.render_to_response(dict(
            providers=[
                {
                    'name': p.name if p.name else 'id:%s' % p.id,
                    'state': mqtt.spread.topic.State(
                        mqtt.spread.address.ProviderAddress(bam.project.id,
                                                            managers.Dali.__name__,
                                                            p.managerID,
                                                            p.type,
                                                            p.id,
                                                            '+')
                    ),
                }
                for p in bam.models.Provider.objects.filter(
                    type__in=[
                        lights.DaliDimmer.__name__,
                        lights.DaliTunableWhite.__name__,
                        lights.DaliRelay.__name__
                    ]
                )
            ],
            config=bam.broker_auth(),
            fade_times={variant: int(variant.split('ft')[1]) / 10 for variant in lights.FadeTime.index_of},
            fade_rates={variant: int(variant.split('fr')[1]) / 10 for variant in lights.FadeRate.index_of if variant != ''},
            scene_ids=list(range(0, 16)),
            group_ids=[list(range(4*i, 4*i+4)) for i in range(0, 4)],
            curves=lights.DimmingCurve.index_of,
        ))

==> spread-5.3.0.5-py3-none-any.whl: spread_dashboard/dali/views.py <==
from django.views.generic import TemplateView
from django.contrib.auth.mixins import LoginRequiredMixin

from spread_core import mqtt
from spread_core.bam.dali.providers import lights
from spread_core.bam.dali import managers
from spread_dashboard.utils import app
from ..project import bam
from ..responses import Success


class DaliDimmer(LoginRequiredMixin, TemplateView):
    template_name = 'dali/dimmer.html'

    def get(self, request, *args, **kwargs):
        provider_id = kwargs.get('id')
        if request.GET:
            return Success(True)
        return self.render_to_response(dict(
            providers=[
                {
                    'name': p.name if p.name else 'id:%s' % p.id,
                    'state': mqtt.spread.topic.State(
                        mqtt.spread.address.ProviderAddress(app().project_id,
                                                            managers.Dali.__name__,
                                                            p.managerID,
                                                            p.type,
                                                            p.id,
                                                            '+')
                    ),
                }
                for p in bam.models.Provider.objects.filter(
                    type__in=[
                        lights.DaliDimmer.__name__,
                        lights.DaliTunableWhite.__name__,
                        lights.DaliRelay.__name__
                    ]
                )
            ],
            config=bam.broker_auth(),
            fade_times={variant: int(variant.split('ft')[1]) / 10 for variant in lights.FadeTime.index_of},
            fade_rates={variant: int(variant.split('fr')[1]) / 10 for variant in lights.FadeRate.index_of if variant != ''},
            scene_ids=list(range(0, 16)),
            group_ids=[list(range(4*i, 4*i+4)) for i in range(0, 4)],
            curves=lights.DimmingCurve.index_of,
        ))
